# Changelog
## 1.0.5 (2021-03-30)
### Features
- Add a dynamic factory reset REST API call

### Misc
- Set marshmallow requirement to less than 4.0.0


## 1.0.4 (2021-01-25)
### Misc
- Include LICENSE, CHANGES.md and README.md in the PyPi package.


## 1.0.3 (2021-01-25)
### Misc
- Extend supported version of `importlib-metadata` to the lowest.
